@@ -216,13 +216,10 @@ class Broadcast:
                     self.postEvent(ExceptionThrowed(exception=e, event=event))
                 raise
             finally:
-                if not complete_finished:
-                    _, exception, tb = sys.exc_info()
-                    await dii.exec_lifecycle("afterDispatch", exception, tb)
-                    await dii.exec_lifecycle("afterTargetExec", exception, tb)
-                    await dii.exec_lifecycle("afterExecution", exception, tb)
-                else:
-                    await dii.exec_lifecycle("afterDispatch")
+                _, exception, tb = sys.exc_info()
+                await dii.exec_lifecycle("afterDispatch", exception, tb)
+                await dii.exec_lifecycle("afterTargetExec", exception, tb)
+                await dii.exec_lifecycle("afterExecution", exception, tb)
 
                 if is_exectarget and not track_logs.fluent_success:
                     current_paths = target.param_paths
