@@ -37,13 +37,20 @@ class BaseDispatcher(metaclass=ABCMeta):
         """
         pass
 
-    def afterDispatch(self, interface: "DispatcherInterface"):
+    def afterDispatch(
+        self,
+        interface: "DispatcherInterface",
+        exception: Optional[Exception],
+        tb: Optional[TracebackType],
+    ):
         """生命周期钩子: 在参数被解析完后被调用
 
         Args:
             interface (DispatcherInterface): `Dispatcher` 服务的主要对象, 可以从其中获取以下信息:
              - 当前解析中的参数的信息;
              - 当前执行的信息, 比如正在处理的事件, `Listener`/`ExecTarget` etc.;
+            exception (Optional[Exception]): 可能存在的异常对象, 若为 None 则表示无异常被抛出, 执行顺利完成.
+            tb (Optional[TracebackType]): 可能存在的异常堆栈对象, 若为 None 则表示无异常被抛出, 执行顺利完成.
         """
         pass
 
